;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "llama" "20260504.1734"
  "Compact syntax for short lambda."
  '((emacs  "26.1")
    (compat "31.0"))
  :url "https://github.com/tarsius/llama"
  :commit "57a8988eb4a624dd1efc583412fe8660741eaa50"
  :revdesc "57a8988eb4a6"
  :keywords '("extensions"))
